@@ -3,8 +3,13 @@
 """Error classes for py4cytoscape.
 """
 
+# External library imports
 import sys
 
+# Internal module convenience imports
+from .py4cytoscape_logger import show_error
+
+
 """Copyright 2020 The Cytoscape Consortium
 
 Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
@@ -22,8 +27,29 @@ TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR TH
 """
 
 class CyError(Exception):
+    """Create an error describing a Cytoscape or py4cytoscape fault.
+
+    Args:
+        message_text (str): text describing error condition
+        caller (str): name of function in which error is to be reported
+
+    Returns:
+         CyError: contains the text message and error location
+
+    Raises:
+        none
+
+    Examples:
+        >>> CyError('Invalid column name')
+        'In commands_get(): Invalid column name'
+        >>> CyError('slot must be an integer between 1 and 9', caller=sys._getframe(1).f_code.co_name)
+        'In get_network_suid(): slot must be an integer between 1 and 9'
+    """
 
     def __init__(self, message_text, caller=None):
         if caller is None: caller = sys._getframe(1).f_code.co_name
-        super().__init__(f'In {caller}(): {message_text}')
+        whole_error = f'In {caller}(): {message_text}'
+        super().__init__(whole_error)
+        show_error(whole_error)     # was: print(whole_error, file=sys.stderr)
+
 
