@@ -19,7 +19,9 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY
 TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 
-DEFAULT_BASE_URL: str = 'http://127.0.0.1:1234/v1'
+import os
+
+DEFAULT_BASE_URL = os.environ.get('DEFAULT_BASE_URL') or 'http://127.0.0.1:1234/v1'
 
 # External library imports
 import urllib.parse
@@ -34,6 +36,9 @@ from . import cytoscape_system
 from .exceptions import CyError
 from .py4cytoscape_logger import narrate
 
+# print(f'Starting {__name__} module')
+
+
 # ==============================================================================
 # I. Package Utility Functions
 # ------------------------------------------------------------------------------
