@@ -9,20 +9,23 @@ set up as part of py4cytoscape startup. However, the workflow can set different
 them. A sandbox can contain both files and directories, and the user can transfer files between a sandbox and the
 workflow's native file system (e.g., a remote Notebook's server).
 
+If a sandbox is defined, all Cytoscape functions read and write files to it by default.
+
 Thus, is it possible to build workflows that don't depend on the structure of the Cytoscape workstation's file system.
 Such workflows can store workflow data files along with other workflow files on a remote Notebook server, then transfer
 them to a sandbox only when Cytoscape will need them. Conversely, when Cytoscape creates a file in a sandbox (e.g.,
 exporting an image), the workflow can transfer the file to workflow storage.
 
 A special case is when py4cytoscape is running on the same workstation as Cytoscape. The default sandbox is considered
-to be the whole workstation file system, and the workflow is responsible for providing full file paths to Cytoscape
-functions. Alternatively, the workflow could also define a sandbox, and then move files in and out of it just as a
-remote Notebook would.
+to be directory that's current for the Python kernel. Alternatively, the workflow could also define a sandbox, and
+then move files in and out of it just as a remote Notebook would.
 
     See Also:
-        Sandboxing in Concepts section in the py4cytoscape User Manual.
+        `Sandboxing <https://py4cytoscape.readthedocs.io/en/latest/concepts.html#sandboxing>`_ in the Concepts section in the py4cytoscape User Manual.
 """
 
+"""Note that there is more detailed commentary and lower level functions in py4cytsocape_sandbox.py."""
+
 """Copyright 2020 The Cytoscape Consortium
 
 Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
@@ -59,8 +62,8 @@ def sandbox_set(sandbox_name, copy_samples=True, reinitialize=True, base_url=DEF
     """Set a new default sandbox, creating it if necessary.
 
     A sandbox is the root for the file system used for all file operations. When running standalone
-    on the same workstation as Cytoscape, the default sandbox is the entire file system on the
-    Cytoscape workstation. When running in a Notebook or remote server, the default sandbox is the
+    on the same workstation as Cytoscape, the default sandbox is the directory that's current for
+    the Python kernel. When running in a Notebook or remote server, the default sandbox is the
     'default_sandbox' created automatically under the under the ``filetransfer`` directory in the
     CytoscapeConfiguration directory. Naming a sandbox with this function creates a new
     sub-directory as a sibling to 'default_sandbox' and uses it for subsequent file operations.
@@ -95,7 +98,7 @@ def sandbox_set(sandbox_name, copy_samples=True, reinitialize=True, base_url=DEF
         'C:\\Users\\CyDeveloper\\CytoscapeConfiguration\\filetransfer\\mySand'
 
     See Also:
-        Sandboxing in Concepts section in the py4cytoscape User Manual.
+        `Sandboxing <https://py4cytoscape.readthedocs.io/en/latest/concepts.html#sandboxing>`_ in the Concepts section in the py4cytoscape User Manual.
     """
     if sandbox_name: sandbox_name = sandbox_name.strip()
 
@@ -139,7 +142,7 @@ def sandbox_remove(sandbox_name=None, base_url=DEFAULT_BASE_URL):
         {'sandboxPath': 'C:\\Users\\CyDeveloper\\CytoscapeConfiguration\\filetransfer\\default_sandbox', 'existed': True}
 
     See Also:
-        Sandboxing in Concepts section in the py4cytoscape User Manual.
+        `Sandboxing <https://py4cytoscape.readthedocs.io/en/latest/concepts.html#sandboxing>`_ in the Concepts section in the py4cytoscape User Manual.
     """
     if sandbox_name: sandbox_name = sandbox_name.strip()
 
@@ -150,8 +153,9 @@ def sandbox_remove(sandbox_name=None, base_url=DEFAULT_BASE_URL):
     # removal is essentially an error because it's very bad to remove the whole Cytoscape file system.
     default_sandbox_name = get_default_sandbox()['sandboxName']
     current_sandbox_before_remove = get_current_sandbox_name()
-    res = _sandbox_op(f'filetransfer removeSandbox', sandbox_name, base_url)
-    if not sandbox_name or sandbox_name == current_sandbox_before_remove:
+
+    res = _sandbox_op(f'filetransfer removeSandbox', sandbox_name, base_url=base_url)
+    if sandbox_name is None or sandbox_name == current_sandbox_before_remove:
         set_current_sandbox(default_sandbox_name, get_default_sandbox_path()) # There is no more current sandbox ... wipe out name of sandbox
         sandbox_name = current_sandbox_before_remove
 
@@ -206,11 +210,10 @@ def sandbox_get_file_info(file_name, sandbox_name=None, base_url=DEFAULT_BASE_UR
         {'filePath': 'C:\\Users\\CyDeveloper\\CytoscapeConfiguration\\filetransfer\\mySand\\test.png', 'modifiedTime': '2020-09-24 14:10:08.0560', 'isFile': True}
 
     See Also:
-        Sandboxing in Concepts section in the py4cytoscape User Manual.
+        `Sandboxing <https://py4cytoscape.readthedocs.io/en/latest/concepts.html#sandboxing>`_ in the Concepts section in the py4cytoscape User Manual.
     """
-    file_name_param = f'fileName="{file_name.strip()}"' if file_name else ''
     try:
-        return _sandbox_op(f'filetransfer getFileInfo {file_name_param}', sandbox_name, base_url)
+        return _sandbox_op(f'filetransfer getFileInfo', sandbox_name, file_name=file_name, base_url=base_url)
     except Exception as e:
         # This is a nasty case ... there isn't much way for getFileInfo to fail as long as the FileTransfer app
         # is installed. We'll assume failure means it isn't installed. And if that's so, it must mean that we're
@@ -265,7 +268,7 @@ def sandbox_send_to(source_file, dest_file=None, overwrite=True, sandbox_name =
         {'filePath': 'C:\\Users\\CyDeveloper\\CytoscapeConfiguration\\filetransfer\\default_sandbox\\myData.csv'}
 
     See Also:
-        Sandboxing in Concepts section in the py4cytoscape User Manual.
+        `Sandboxing <https://py4cytoscape.readthedocs.io/en/latest/concepts.html#sandboxing>`_ in the Concepts section in the py4cytoscape User Manual.
     """
     try:
         with open(source_file, mode='rb') as file:
@@ -277,8 +280,7 @@ def sandbox_send_to(source_file, dest_file=None, overwrite=True, sandbox_name =
     if not dest_file or not dest_file.strip():
         head, dest_file = os.path.split(source_file)
 
-    dest_file_param = f'fileName="{dest_file}"' if dest_file else ''
-    return _sandbox_op(f'filetransfer toSandbox fileByteCount={len(file_content)} {dest_file_param} overwrite={overwrite} fileBase64="{file_content64}"', sandbox_name, base_url=base_url)
+    return _sandbox_op(f'filetransfer toSandbox fileByteCount={len(file_content)} overwrite={overwrite} fileBase64="{file_content64}"', sandbox_name, file_name=dest_file, base_url=base_url)
 
 @cy_log
 def sandbox_get_from(source_file, dest_file=None, overwrite=True, sandbox_name = None, base_url=DEFAULT_BASE_URL):
@@ -313,7 +315,7 @@ def sandbox_get_from(source_file, dest_file=None, overwrite=True, sandbox_name =
         {'filePath': 'C:\\Users\\CyDeveloper\\Cytofiles\\workspace.cys'}
 
     See Also:
-        Sandboxing in Concepts section in the py4cytoscape User Manual.
+        `Sandboxing <https://py4cytoscape.readthedocs.io/en/latest/concepts.html#sandboxing>`_ in the Concepts section in the py4cytoscape User Manual.
     """
     source_file = source_file.strip() if source_file else ''
     if not dest_file or not dest_file.strip():
@@ -322,8 +324,7 @@ def sandbox_get_from(source_file, dest_file=None, overwrite=True, sandbox_name =
     if not overwrite and os.path.exists(dest_file):
         raise CyError(f'File "{dest_file}" already exists')
 
-    source_file_param = f'fileName="{source_file}"' if source_file else ''
-    res = _sandbox_op(f'filetransfer fromSandbox {source_file_param}', sandbox_name, base_url)
+    res = _sandbox_op(f'filetransfer fromSandbox', sandbox_name, file_name=source_file, base_url=base_url)
 
     file_content = base64.b64decode(res['fileBase64'], validate=True)
     try:
@@ -366,14 +367,16 @@ def sandbox_remove_file(file_name, sandbox_name=None, base_url=DEFAULT_BASE_URL)
         {'filePath': 'C:\\Users\\CyDeveloper\\Cytofiles\\workspace.cys', 'existed': False}
 
     See Also:
-        Sandboxing in Concepts section in the py4cytoscape User Manual.
+        `Sandboxing <https://py4cytoscape.readthedocs.io/en/latest/concepts.html#sandboxing>`_ in the Concepts section in the py4cytoscape User Manual.
     """
-    file_name_param = f'fileName="{file_name.strip()}"' if file_name else ''
-    return _sandbox_op(f'filetransfer removeFile {file_name_param}', sandbox_name, base_url)
+    return _sandbox_op(f'filetransfer removeFile', sandbox_name, file_name=file_name, base_url=base_url)
 
-def _sandbox_op(command, sandbox_name, base_url):
-    if sandbox_name: sandbox_name = sandbox_name.strip()
-    if not sandbox_name:
+def _sandbox_op(command, sandbox_name, file_name=None, base_url=DEFAULT_BASE_URL):
+    if file_name: file_name = file_name.strip()
+    if sandbox_name:
+        sandbox_name = sandbox_name.strip()
+        sandbox_path = get_current_sandbox_path()
+    else:
         # An empty sandbox name (either None or "") means to use the currently set sandbox (from sandbox_set).
         # Fetch the current sandbox name and use it. After that, the sandbox name could still be None ... meaning
         # that either there is no sandbox set yet, or the entire raw Cytoscape file system is being used as a sandbox.
@@ -391,6 +394,12 @@ def _sandbox_op(command, sandbox_name, base_url):
         # Given all of this, we let the do_initialize_sandbox figure out whether an initialization is needed, and
         # beyond that, what the current sandbox name is.
         sandbox_name, sandbox_path = commands.do_initialize_sandbox(base_url=base_url)
-    sandbox_param = f' sandboxName="{sandbox_name}"' if sandbox_name else ''
-    res = commands.commands_post(command + sandbox_param, base_url=base_url)
+
+    if sandbox_name:
+        command += f' sandboxName="{sandbox_name}"'
+    elif file_name:
+        file_name = os.path.join(sandbox_path, file_name)
+    if file_name: command += f' fileName="{file_name}"'
+
+    res = commands.commands_post(command, base_url=base_url)
     return res
