@@ -68,7 +68,7 @@ def map_visual_property(visual_prop, table_column, mapping_type, table_column_va
         network (SUID or str or None): Name or SUID of a network. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -168,7 +168,7 @@ def update_style_mapping(style_name, mapping, base_url=DEFAULT_BASE_URL):
         style_name (str): name for style
         mapping (dict): a single visual property mapping, see ``map_visual_property()``
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -188,6 +188,10 @@ def update_style_mapping(style_name, mapping, base_url=DEFAULT_BASE_URL):
     """
     visual_prop_name = mapping['visualProperty']
 
+    if style_name is None:
+        style_name = 'default'
+        narrate(f'style_name not specified; updating "default" style.')
+
     # check if vp exists already
     res = commands.cyrest_get(f'styles/{style_name}/mappings', base_url=base_url)
     vp_list = [prop['visualProperty'] for prop in res]
@@ -213,7 +217,7 @@ def delete_style_mapping(style_name, visual_prop, base_url=DEFAULT_BASE_URL):
         style_name (str): name for style
         visual_prop (str): name of visual property to delete
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -228,7 +232,7 @@ def delete_style_mapping(style_name, visual_prop, base_url=DEFAULT_BASE_URL):
         ''
     """
     # check if vp exists already
-    res = commands.cyrest_get('styles/' + style_name + '/mappings', base_url=base_url)
+    res = commands.cyrest_get(f'styles/{style_name}/mappings', base_url=base_url)
     vp_list = [prop['visualProperty'] for prop in res]
     exists = visual_prop in vp_list
 
@@ -253,7 +257,7 @@ def get_style_mapping(style_name, visual_prop, base_url=DEFAULT_BASE_URL):
         style_name (str): name for style
         visual_prop (str): the name of the visual property
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -270,6 +274,10 @@ def get_style_mapping(style_name, visual_prop, base_url=DEFAULT_BASE_URL):
     See Also:
         :meth:`map_visual_property`
     """
+    if style_name is None:
+        style_name = 'default'
+        narrate(f'style_name not specified; accessing "default" style.')
+
     # check if vp exists already
     res = commands.cyrest_get(f'styles/{style_name}/mappings', base_url=base_url)
     for prop in res:
@@ -288,7 +296,7 @@ def get_style_all_mappings(style_name, base_url=DEFAULT_BASE_URL):
     Args:
         style_name (str): name for style
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -306,6 +314,10 @@ def get_style_all_mappings(style_name, base_url=DEFAULT_BASE_URL):
     See Also:
         :meth:`map_visual_property`
     """
+    if style_name is None:
+        style_name = 'default'
+        narrate(f'style_name not specified; accessing "default" style.')
+
     res = commands.cyrest_get(f'styles/{style_name}/mappings', base_url=base_url)
     return res
 
@@ -320,7 +332,7 @@ def get_style_all_mappings(style_name, base_url=DEFAULT_BASE_URL):
 # TODO: R documented colors list incorrectly
 @cy_log
 def set_node_border_color_mapping(table_column, table_column_values=None, colors=None, mapping_type='c',
-                                  default_color=None, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                                  default_color=None, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to colors to set the node border color.
 
     Args:
@@ -333,7 +345,7 @@ def set_node_border_color_mapping(table_column, table_column_values=None, colors
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -365,7 +377,7 @@ def set_node_border_color_mapping(table_column, table_column_values=None, colors
 
 @cy_log
 def set_node_border_opacity_mapping(table_column, table_column_values=None, opacities=None, mapping_type='c',
-                                    default_opacity=None, style_name='default', network=None,
+                                    default_opacity=None, style_name=None, network=None,
                                     base_url=DEFAULT_BASE_URL):
     """Set opacity for node border only.
 
@@ -379,7 +391,7 @@ def set_node_border_opacity_mapping(table_column, table_column_values=None, opac
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -418,7 +430,7 @@ def set_node_border_opacity_mapping(table_column, table_column_values=None, opac
 
 @cy_log
 def set_node_border_width_mapping(table_column, table_column_values=None, widths=None, mapping_type='c',
-                                  default_width=None, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                                  default_width=None, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to widths to set the node border width.
 
     Args:
@@ -431,7 +443,7 @@ def set_node_border_width_mapping(table_column, table_column_values=None, widths
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -462,7 +474,7 @@ def set_node_border_width_mapping(table_column, table_column_values=None, widths
 
 @cy_log
 def set_node_color_mapping(table_column, table_column_values=None, colors=None, mapping_type='c', default_color=None,
-                           style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                           style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to colors to set the node fill color.
 
     Args:
@@ -475,7 +487,7 @@ def set_node_color_mapping(table_column, table_column_values=None, colors=None,
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -512,7 +524,7 @@ def set_node_color_mapping(table_column, table_column_values=None, colors=None,
 
 @cy_log
 def set_node_combo_opacity_mapping(table_column, table_column_values=None, opacities=None, mapping_type='c',
-                                   default_opacity=None, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                                   default_opacity=None, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Set opacity for node fill, border and label all together.
 
     Args:
@@ -525,7 +537,7 @@ def set_node_combo_opacity_mapping(table_column, table_column_values=None, opaci
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -573,7 +585,7 @@ def set_node_combo_opacity_mapping(table_column, table_column_values=None, opaci
 
 @cy_log
 def set_node_fill_opacity_mapping(table_column, table_column_values=None, opacities=None, mapping_type='c',
-                                  default_opacity=None, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                                  default_opacity=None, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Set opacity for node fill only.
 
     Args:
@@ -586,7 +598,7 @@ def set_node_fill_opacity_mapping(table_column, table_column_values=None, opacit
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -625,7 +637,7 @@ def set_node_fill_opacity_mapping(table_column, table_column_values=None, opacit
 
 @cy_log
 def set_node_font_face_mapping(table_column, table_column_values=None, fonts=None, mapping_type='d', default_font=None,
-                               style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                               style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Sets font face for node labels.
 
     Args:
@@ -638,7 +650,7 @@ def set_node_font_face_mapping(table_column, table_column_values=None, fonts=Non
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -668,7 +680,7 @@ def set_node_font_face_mapping(table_column, table_column_values=None, fonts=Non
 
 
 def set_node_font_size_mapping(table_column, table_column_values=None, sizes=None, mapping_type='c', default_size=None,
-                               style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                               style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to sizes to set the node size.
 
     Args:
@@ -681,7 +693,7 @@ def set_node_font_size_mapping(table_column, table_column_values=None, sizes=Non
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -711,7 +723,7 @@ def set_node_font_size_mapping(table_column, table_column_values=None, sizes=Non
 
 @cy_log
 def set_node_height_mapping(table_column, table_column_values=None, heights=None, mapping_type='c', default_height=None,
-                            style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                            style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to the node heights.
 
     Args:
@@ -724,7 +736,7 @@ def set_node_height_mapping(table_column, table_column_values=None, heights=None
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -756,7 +768,7 @@ def set_node_height_mapping(table_column, table_column_values=None, heights=None
 
 
 @cy_log
-def set_node_label_mapping(table_column, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+def set_node_label_mapping(table_column, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Pass the values from a table column to display as node labels.
 
     Args:
@@ -765,7 +777,7 @@ def set_node_label_mapping(table_column, style_name='default', network=None, bas
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -795,7 +807,7 @@ def set_node_label_mapping(table_column, style_name='default', network=None, bas
 
 @cy_log
 def set_node_label_color_mapping(table_column, table_column_values=None, colors=None, mapping_type='c',
-                                 default_color=None, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                                 default_color=None, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to colors to set the node border color.
 
     Args:
@@ -808,7 +820,7 @@ def set_node_label_color_mapping(table_column, table_column_values=None, colors=
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -840,7 +852,7 @@ def set_node_label_color_mapping(table_column, table_column_values=None, colors=
 
 @cy_log
 def set_node_label_opacity_mapping(table_column, table_column_values=None, opacities=None, mapping_type='c',
-                                   default_opacity=None, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                                   default_opacity=None, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Sets opacity for node label only.
 
     Args:
@@ -853,7 +865,7 @@ def set_node_label_opacity_mapping(table_column, table_column_values=None, opaci
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -892,7 +904,7 @@ def set_node_label_opacity_mapping(table_column, table_column_values=None, opaci
 
 @cy_log
 def set_node_shape_mapping(table_column, table_column_values=None, shapes=None, default_shape=None,
-                           style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                           style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to shapes to set the node shape.
 
     Args:
@@ -904,7 +916,7 @@ def set_node_shape_mapping(table_column, table_column_values=None, shapes=None,
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -931,7 +943,7 @@ def set_node_shape_mapping(table_column, table_column_values=None, shapes=None,
 # TODO: R documentation claims this is about font sizes
 @cy_log
 def set_node_size_mapping(table_column, table_column_values=None, sizes=None, mapping_type='c', default_size=None,
-                          style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                          style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to node sizes.
 
     Args:
@@ -944,7 +956,7 @@ def set_node_size_mapping(table_column, table_column_values=None, sizes=None, ma
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -976,7 +988,7 @@ def set_node_size_mapping(table_column, table_column_values=None, sizes=None, ma
 
 
 @cy_log
-def set_node_tooltip_mapping(table_column, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+def set_node_tooltip_mapping(table_column, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Pass the values from a table column to display as node tooltips.
 
     Args:
@@ -985,7 +997,7 @@ def set_node_tooltip_mapping(table_column, style_name='default', network=None, b
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -1013,7 +1025,7 @@ def set_node_tooltip_mapping(table_column, style_name='default', network=None, b
 
 @cy_log
 def set_node_width_mapping(table_column, table_column_values=None, widths=None, mapping_type='c', default_width=None,
-                           style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                           style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to the node widths.
 
     Args:
@@ -1026,7 +1038,7 @@ def set_node_width_mapping(table_column, table_column_values=None, widths=None,
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -1065,7 +1077,37 @@ def set_node_width_mapping(table_column, table_column_values=None, widths=None,
 # TODO: Come back to this once we figure out what it should be doing
 @cy_log
 def set_edge_color_mapping(table_column, table_column_values=None, colors=None, mapping_type='c', default_color=None,
-                           style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                           style_name=None, network=None, base_url=DEFAULT_BASE_URL):
+    """Map table column values to colors to set the edge color.
+
+    Args:
+        table_column (str): Name of Cytoscape table column to map values from
+        table_column_values (list): List of values from Cytoscape table to be used in mapping
+        colors (list): list of hex colors to map to ``table_column_values``
+        mapping_type (str): continuous, discrete or passthrough (c,d,p); default is continuous
+        default_color (str): Hex color to set as default
+        style_name (str): name for style
+        network (SUID or str or None): Name or SUID of a network or view. Default is the
+            "current" network active in Cytoscape.
+        base_url (str): Ignore unless you need to specify a custom domain,
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
+            and the latest version of the CyREST API supported by this version of py4cytoscape.
+
+    Returns:
+        str: ''
+
+    Raises:
+        CyError: if invalid color, table column doesn't exist, table column values doesn't match values list, or invalid style name, network or mapping type
+        requests.exceptions.RequestException: if can't connect to Cytoscape or Cytoscape returns an error
+
+    Examples:
+        >>> set_edge_color_mapping('EdgeBetweenness', [1.0, 16.36], ['#FBE723', '#440256'], style_name='galFiltered Style')
+        ''
+        >>> set_edge_color_mapping('EdgeBetweenness', ['1', '2'], ['#FFFF00', '#00FF00'], 'd', style_name='galFiltered Style')
+        ''
+        >>> set_edge_color_mapping('EdgeBetweennessColor', mapping_type='p', default_color='#654321', style_name='galFiltered Style')
+        ''
+    """
     verify_hex_colors(colors)
 
     # set default
@@ -1075,8 +1117,9 @@ def set_edge_color_mapping(table_column, table_column_values=None, colors=None,
 
     # perform mapping for COLOR (i.e., when arrowColorMatchesEdge=T)
     # TODO: This code checks table_column, but the R code does not
-    res = _update_visual_property('EDGE_UNSELECTED_PAINT', table_column, table_column_values, colors, mapping_type,
-                                  style_name, network, base_url, table='edge')
+    res = _update_visual_property('EDGE_UNSELECTED_PAINT', table_column, table_column_values=table_column_values, range_map=colors,
+                                  mapping_type=mapping_type, style_name=style_name, network=network,
+                                  base_url=base_url, table='edge')
     if res is not None:
         # perform mapping for STROKE (i.e., when arrowColorMatchesEdge=F)
         res = _update_visual_property('EDGE_STROKE_UNSELECTED_PAINT', table_column,
@@ -1088,7 +1131,7 @@ def set_edge_color_mapping(table_column, table_column_values=None, colors=None,
 
 @cy_log
 def set_edge_font_face_mapping(table_column, table_column_values=None, fonts=None, mapping_type='d', default_font=None,
-                               style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                               style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Sets font face for edge labels.
 
     Args:
@@ -1101,7 +1144,7 @@ def set_edge_font_face_mapping(table_column, table_column_values=None, fonts=Non
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -1130,7 +1173,7 @@ def set_edge_font_face_mapping(table_column, table_column_values=None, fonts=Non
 
 @cy_log
 def set_edge_font_size_mapping(table_column, table_column_values=None, sizes=None, mapping_type='c', default_size=None,
-                               style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                               style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to sizes to set the edge size.
 
     Args:
@@ -1143,7 +1186,7 @@ def set_edge_font_size_mapping(table_column, table_column_values=None, sizes=Non
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -1172,7 +1215,7 @@ def set_edge_font_size_mapping(table_column, table_column_values=None, sizes=Non
 
 
 @cy_log
-def set_edge_label_mapping(table_column, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+def set_edge_label_mapping(table_column, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Pass the values from a table column to display as edge labels.
 
     Args:
@@ -1181,7 +1224,7 @@ def set_edge_label_mapping(table_column, style_name='default', network=None, bas
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -1211,7 +1254,7 @@ def set_edge_label_mapping(table_column, style_name='default', network=None, bas
 
 @cy_log
 def set_edge_label_color_mapping(table_column, table_column_values=None, colors=None, mapping_type='c',
-                                 default_color=None, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                                 default_color=None, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to colors to set the edge border color.
 
     Args:
@@ -1256,7 +1299,7 @@ def set_edge_label_color_mapping(table_column, table_column_values=None, colors=
 
 @cy_log
 def set_edge_label_opacity_mapping(table_column, table_column_values=None, opacities=None, mapping_type='c',
-                                   default_opacity=None, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                                   default_opacity=None, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Sets opacity for edge label only.
 
     Args:
@@ -1308,7 +1351,7 @@ def set_edge_label_opacity_mapping(table_column, table_column_values=None, opaci
 
 @cy_log
 def set_edge_line_style_mapping(table_column, table_column_values=None, line_styles=None, default_line_style='SOLID',
-                                style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                                style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to styles to set the edge style.
 
     Args:
@@ -1348,7 +1391,7 @@ def set_edge_line_style_mapping(table_column, table_column_values=None, line_sty
 
 @cy_log
 def set_edge_line_width_mapping(table_column, table_column_values=None, widths=None, mapping_type='c',
-                                default_width=None, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                                default_width=None, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to widths to set the node border width.
 
     Args:
@@ -1394,7 +1437,7 @@ def set_edge_line_width_mapping(table_column, table_column_values=None, widths=N
 
 @cy_log
 def set_edge_opacity_mapping(table_column, table_column_values=None, opacities=None, mapping_type='c',
-                             default_opacity=None, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                             default_opacity=None, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to opacities to set the edge opacity.
 
     Args:
@@ -1446,7 +1489,7 @@ def set_edge_opacity_mapping(table_column, table_column_values=None, opacities=N
 # TODO: This is the same as set_edge_target_arrow_shape_mapping???
 @cy_log
 def set_edge_target_arrow_maping(table_column, table_column_values=None, shapes=None, default_shape='ARROW',
-                                  style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                                  style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to shapes to set the target arrow shape.
 
     Args:
@@ -1489,7 +1532,7 @@ def set_edge_target_arrow_maping(table_column, table_column_values=None, shapes=
 # TODO: This is the same as set_edge_source_arrow_shape_mapping???
 @cy_log
 def set_edge_source_arrow_mapping(table_column, table_column_values=None, shapes=None, default_shape='ARROW',
-                                  style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+                                  style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Map table column values to shapes to set the source arrow shape.
 
     Args:
@@ -1531,7 +1574,7 @@ def set_edge_source_arrow_mapping(table_column, table_column_values=None, shapes
 
 @cy_log
 def set_edge_target_arrow_color_mapping(table_column, table_column_values=None, colors=None, mapping_type='c',
-                                        default_color=None, style_name='default', network=None,
+                                        default_color=None, style_name=None, network=None,
                                         base_url=DEFAULT_BASE_URL):
     """Map table column values to colors to set the target arrow color.
 
@@ -1578,7 +1621,7 @@ def set_edge_target_arrow_color_mapping(table_column, table_column_values=None,
 
 @cy_log
 def set_edge_source_arrow_color_mapping(table_column, table_column_values=None, colors=None, mapping_type='c',
-                                        default_color=None, style_name='default', network=None,
+                                        default_color=None, style_name=None, network=None,
                                         base_url=DEFAULT_BASE_URL):
     """Map table column values to colors to set the source arrow color.
 
@@ -1624,7 +1667,7 @@ def set_edge_source_arrow_color_mapping(table_column, table_column_values=None,
 
 @cy_log
 def set_edge_target_arrow_shape_mapping(table_column, table_column_values=None, shapes=None,
-                                        default_shape=None, style_name='default', network=None,
+                                        default_shape=None, style_name=None, network=None,
                                         base_url=DEFAULT_BASE_URL):
     """Map table column values to colors to set the target arrow color.
 
@@ -1664,7 +1707,7 @@ def set_edge_target_arrow_shape_mapping(table_column, table_column_values=None,
 
 @cy_log
 def set_edge_source_arrow_shape_mapping(table_column, table_column_values=None, shapes=None,
-                                        default_shape=None, style_name='default', network=None,
+                                        default_shape=None, style_name=None, network=None,
                                         base_url=DEFAULT_BASE_URL):
     """Map table column values to colors to set the source arrow color.
 
@@ -1702,7 +1745,7 @@ def set_edge_source_arrow_shape_mapping(table_column, table_column_values=None,
                                         base_url=base_url)
 
 @cy_log
-def set_edge_tooltip_mapping(table_column, style_name='default', network=None, base_url=DEFAULT_BASE_URL):
+def set_edge_tooltip_mapping(table_column, style_name=None, network=None, base_url=DEFAULT_BASE_URL):
     """Pass the values from a table column to display as edge tooltips.
 
     Args:
@@ -1732,7 +1775,7 @@ def set_edge_tooltip_mapping(table_column, style_name='default', network=None, b
 
 # Check table column, create the visual property map, and update Cytoscape's copy of the visual property
 def _update_visual_property(visual_prop_name, table_column, table_column_values=[], range_map=[], mapping_type='c',
-                            style_name='default', network=None, base_url=DEFAULT_BASE_URL,
+                            style_name=None, network=None, base_url=DEFAULT_BASE_URL,
                             supported_mappings=['c', 'd', 'p'], table='node'):
     if range_map is not None: range_map = [str(x) for x in range_map]  # CyREST requires strings
 
